.. _tutorials:

=========
Tutorials
=========


These tutorials illustrate use cases the pydov package supports, split
up by different topics each setup as a `jupyter notebook`_
you can run yourself.

.. _jupyter notebook: http://jupyter.org/


To run these interactively online without installation, use the following binder link:

.. image:: https://mybinder.org/badge.svg
   :target: https://mybinder.org/v2/gh/dov-vlaanderen/pydov/master?filepath=docs%2Fnotebooks


.. toctree::
   :maxdepth: 1

   notebooks/search_boringen.ipynb
   notebooks/search_sonderingen.ipynb
   notebooks/search_grondwaterfilters.ipynb
   notebooks/search_grondwatermonsters.ipynb
   notebooks/search_formele_stratigrafie.ipynb
   notebooks/search_informele_stratigrafie.ipynb
   notebooks/search_hydrogeologische_stratigrafie.ipynb
   notebooks/search_informele_hydrostratigrafie.ipynb
   notebooks/search_lithologische_beschrijvingen.ipynb
   notebooks/search_gecodeerde_lithologie.ipynb
   notebooks/search_geotechnische_codering.ipynb
   notebooks/search_quartaire_stratigrafie.ipynb
   notebooks/search_grondmonsters.ipynb
   notebooks/customizing_object_types.ipynb
   notebooks/caching.ipynb
